pub struct ActiveDungeon {
pub id: DungeonTemplateId,
pub difficulty: i64,
}Fields
id: DungeonTemplateIddifficulty: i64Trait Implementations
Sourceimpl Clone for ActiveDungeon
impl Clone for ActiveDungeon
Sourcefn clone(&self) -> ActiveDungeon
fn clone(&self) -> ActiveDungeon
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ActiveDungeon
impl CustomType for ActiveDungeon
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ActiveDungeon
impl Debug for ActiveDungeon
Sourceimpl Default for ActiveDungeon
impl Default for ActiveDungeon
Sourcefn default() -> ActiveDungeon
fn default() -> ActiveDungeon
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ActiveDungeon
impl<'de> Deserialize<'de> for ActiveDungeon
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActiveDungeon
impl JsonSchema for ActiveDungeon
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ActiveDungeon
impl PartialEq for ActiveDungeon
Sourceimpl Serialize for ActiveDungeon
impl Serialize for ActiveDungeon
Sourceimpl Tsify for ActiveDungeon
impl Tsify for ActiveDungeon
const DECL: &'static str = "export interface ActiveDungeon {\n id: DungeonTemplateId;\n difficulty: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ActiveDungeon
impl StructuralPartialEq for ActiveDungeon