pub struct ActivePetAbility {
pub pet_template_id: PetId,
pub ability_id: AbilityId,
pub charge: i64,
pub max_charge: i64,
}Fields
pet_template_id: PetIdability_id: AbilityIdcharge: i64max_charge: i64Trait Implementations
Sourceimpl Clone for ActivePetAbility
impl Clone for ActivePetAbility
Sourcefn clone(&self) -> ActivePetAbility
fn clone(&self) -> ActivePetAbility
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for ActivePetAbility
impl CustomType for ActivePetAbility
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for ActivePetAbility
impl Debug for ActivePetAbility
Sourceimpl Default for ActivePetAbility
impl Default for ActivePetAbility
Sourcefn default() -> ActivePetAbility
fn default() -> ActivePetAbility
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ActivePetAbility
impl<'de> Deserialize<'de> for ActivePetAbility
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActivePetAbility
impl JsonSchema for ActivePetAbility
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ActivePetAbility
impl PartialEq for ActivePetAbility
Sourceimpl Serialize for ActivePetAbility
impl Serialize for ActivePetAbility
Sourceimpl Tsify for ActivePetAbility
impl Tsify for ActivePetAbility
const DECL: &'static str = "export interface ActivePetAbility {\n pet_template_id: PetId;\n ability_id: AbilityId;\n charge: number;\n max_charge: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ActivePetAbility
impl StructuralPartialEq for ActivePetAbility