pub struct FightEntity {
pub entity_type: EntityType,
pub position: Coordinates,
pub has_big_hp_bar: bool,
pub team: EntityTeam,
}Fields
entity_type: EntityTypeposition: Coordinateshas_big_hp_bar: boolteam: EntityTeamTrait Implementations
Sourceimpl Clone for FightEntity
impl Clone for FightEntity
Sourcefn clone(&self) -> FightEntity
fn clone(&self) -> FightEntity
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FightEntity
impl Debug for FightEntity
Sourceimpl Default for FightEntity
impl Default for FightEntity
Sourcefn default() -> FightEntity
fn default() -> FightEntity
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FightEntity
impl<'de> Deserialize<'de> for FightEntity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FightEntity
impl JsonSchema for FightEntity
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FightEntity
impl PartialEq for FightEntity
Sourceimpl Serialize for FightEntity
impl Serialize for FightEntity
Sourceimpl Tsify for FightEntity
impl Tsify for FightEntity
const DECL: &'static str = "export interface FightEntity {\n entity_type: EntityType;\n position: Coordinates;\n has_big_hp_bar: boolean;\n team: EntityTeam;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for FightEntity
impl StructuralPartialEq for FightEntity