pub struct FightTemplate {Show 21 fields
pub id: FightTemplateId,
pub title: I18nString,
pub power: Option<u64>,
pub fight_entities: Vec<FightEntity>,
pub max_duration_ticks: u64,
pub target_width_cells: u64,
pub starting_fx: String,
pub fight_type: FightType,
pub waves_amount: i64,
pub prepare_fight_script: String,
pub start_script: String,
pub background: String,
pub start_fight_delay_ticks: Option<u64>,
pub prepare_fight_win_duration_ticks: Option<u64>,
pub prepare_fight_lose_duration_ticks: Option<u64>,
pub end_fight_delay_ticks: Option<u64>,
pub bundle_reward_id: Option<BundleId>,
pub stop_on_win: bool,
pub stop_on_lose: bool,
pub show_vs_screen: bool,
pub show_stages: Option<bool>,
}Fields
id: FightTemplateIdtitle: I18nStringpower: Option<u64>fight_entities: Vec<FightEntity>max_duration_ticks: u64target_width_cells: u64starting_fx: Stringfight_type: FightTypewaves_amount: i64prepare_fight_script: Stringstart_script: Stringbackground: Stringstart_fight_delay_ticks: Option<u64>prepare_fight_win_duration_ticks: Option<u64>prepare_fight_lose_duration_ticks: Option<u64>end_fight_delay_ticks: Option<u64>bundle_reward_id: Option<BundleId>stop_on_win: boolstop_on_lose: boolshow_vs_screen: boolshow_stages: Option<bool>Trait Implementations
Sourceimpl Clone for FightTemplate
impl Clone for FightTemplate
Sourcefn clone(&self) -> FightTemplate
fn clone(&self) -> FightTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for FightTemplate
impl CustomType for FightTemplate
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for FightTemplate
impl Debug for FightTemplate
Sourceimpl<'de> Deserialize<'de> for FightTemplate
impl<'de> Deserialize<'de> for FightTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FightTemplate
impl JsonSchema for FightTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FightTemplate
impl PartialEq for FightTemplate
Sourceimpl Serialize for FightTemplate
impl Serialize for FightTemplate
Sourceimpl Tsify for FightTemplate
impl Tsify for FightTemplate
const DECL: &'static str = "export interface FightTemplate {\n id: FightTemplateId;\n title: I18nString;\n power: number | null;\n fight_entities: FightEntity[];\n max_duration_ticks: number;\n target_width_cells: number;\n starting_fx: string;\n fight_type: FightType;\n waves_amount: number;\n prepare_fight_script: string;\n start_script: string;\n background: string;\n start_fight_delay_ticks: number | null;\n prepare_fight_win_duration_ticks: number | null;\n prepare_fight_lose_duration_ticks: number | null;\n end_fight_delay_ticks: number | null;\n bundle_reward_id: BundleId | null;\n stop_on_win: boolean;\n stop_on_lose: boolean;\n show_vs_screen: boolean;\n show_stages: boolean | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for FightTemplate
impl StructuralPartialEq for FightTemplate